SourcePredicate

Enum SourcePredicate 

pub enum SourcePredicate {
    Eq(String, PropertyValue),
    Neq(String, PropertyValue),
    Gt(String, PropertyValue),
    Gte(String, PropertyValue),
    Lt(String, PropertyValue),
    Lte(String, PropertyValue),
    Between(String, PropertyValue, PropertyValue),
    HasKey(String),
    StartsWith(String, String),
    And(Vec<SourcePredicate>),
    Or(Vec<SourcePredicate>),
}
A predicate that can be used in source steps (n_where / e_where).

This is a restricted subset of Predicate intended to be index- and planner-friendly for “source” selection.

Variants



Eq(String, PropertyValue)

Equals: property == value



Neq(String, PropertyValue)

Not equals: property != value



Gt(String, PropertyValue)

Greater than: property > value (for numeric/string)



Gte(String, PropertyValue)

Greater than or equal: property >= value



Lt(String, PropertyValue)

Less than: property < value



Lte(String, PropertyValue)

Less than or equal: property <= value



Between(String, PropertyValue, PropertyValue)

Between (inclusive): min <= property <= max



HasKey(String)

Property exists



StartsWith(String, String)

String starts with prefix



And(Vec<SourcePredicate>)

Logical AND of predicates



Or(Vec<SourcePredicate>)

Logical OR of predicates

Implementations

Source

impl SourcePredicate

pub fn eq(property: impl Into<String>, value: impl Into<PropertyValue>) -> Self

Create an equality predicate

pub fn neq(property: impl Into<String>, value: impl Into<PropertyValue>) -> Self

Create a not-equals predicate

pub fn gt(property: impl Into<String>, value: impl Into<PropertyValue>) -> Self

Create a greater-than predicate

pub fn gte(property: impl Into<String>, value: impl Into<PropertyValue>) -> Self

Create a greater-than-or-equal predicate

pub fn lt(property: impl Into<String>, value: impl Into<PropertyValue>) -> Self

Create a less-than predicate

pub fn lte(property: impl Into<String>, value: impl Into<PropertyValue>) -> Self

Create a less-than-or-equal predicate

pub fn between( property: impl Into<String>, min: impl Into<PropertyValue>, max: impl Into<PropertyValue>, ) -> Self

Create a between predicate (inclusive)

pub fn has_key(property: impl Into<String>) -> Self

Create a has-key predicate

pub fn starts_with( property: impl Into<String>, prefix: impl Into<String>, ) -> Self

Create a starts-with predicate

pub fn and(predicates: Vec<SourcePredicate>) -> Self

Combine predicates with AND

pub fn or(predicates: Vec<SourcePredicate>) -> Self

Combine predicates with OR